<?php
namespace ElementorHero\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Hero extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'Hero_Radio_Player';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Hero Radio Player', 'elementor-hero' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-headphones';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'lambert-widgets' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function register_controls() {
    //general controls (ex content)
    $this->start_controls_section(
      'general_content',
      [
        'label' => esc_html__( 'General', 'elementor-hero' ),
      ]
    );

    $this->add_control(
      'radio_stream',
      [
        'label' => esc_html__( 'Radio Stream Link', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );

    $this->add_control(
      'radio_name',
      [
        'label' => esc_html__( 'Radio Name', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );

    $this->add_control(
      'url_custom_metdata_file',
      [
        'label' => esc_html__( 'Url custom metadata file ( OPTIONAL )', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'description' => esc_html__( 'in case you do not have a standard radio stream and you know the direct url to the metadata file', 'elementor-hero' ),
        'default' => '',
      ]
    );

    $this->add_control(
    			'metadata_file_type',
    			[
    				'label' => esc_html__( 'Metadata File Type ( OPTIONAL )', 'elementor-hero' ),
    				'type' => \Elementor\Controls_Manager::SELECT,
    				'options' => [
              '' => esc_html__( 'default', 'elementor-hero' ),
    					'1' => esc_html__( 'stats?sid=1', 'elementor-hero' ),
    					'2' => esc_html__( '7.html', 'elementor-hero' ),
              '3' => esc_html__( 'status-json.xsl', 'elementor-hero' ),
    					'4' => esc_html__( 'status.xsl', 'elementor-hero' ),
    				],
            'description' => esc_html__( 'in case you do not have a standard radio stream and you know the direct url to the metadata file', 'elementor-hero' ),
    				'default' => '',
    			]
    );

    $this->add_control(
      'azuracast_api_nowplaying_url',
      [
        'label' => esc_html__( 'AzuraCast nowplaying API Url', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'description' => esc_html__( 'ONLY if you will use an AzuraCast radio stream link.', 'elementor-hero' ),
        'default' => '',
      ]
    );

    $this->add_control(
			'azuracast_get_image',
			[
				'label' => esc_html__( 'Grab Artist Photo From AzuraCast API', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'false',
        'description' => esc_html__( 'ONLY if you will use an AzuraCast radio stream link and you want the image to be displayed from there.', 'elementor-hero' ),
			]
		);

    $this->add_control(
      'optional_images_path',
      [
        'label' => esc_html__( 'Path to the artist images/album covers folder (OPTIONAL)', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'description' => esc_html__( 'In case you have your images stored on your server (the same as your website) and you want to use those images for the current playing song. The image name should be identical with the current playing song. Example: Artist Name - Song Name.jpg', 'elementor-hero' ),
        'default' => '',
      ]
    );

    $this->add_control(
      'mscp_pro_api_url',
      [
        'label' => esc_html__( 'The MSCP PRO json Api URL ( OPTIONAL )', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'description' => esc_html__( 'in the case you are using a MSCP PRO radio server. This url will be used if you want to display the cover image from MSCP PRO radio server.', 'elementor-hero' ),
        'default' => '',
      ]
    );

    $this->add_control(
    			'skin',
    			[
    				'label' => esc_html__( 'Skin', 'elementor-hero' ),
    				'type' => \Elementor\Controls_Manager::SELECT,
    				'options' => [
    					'whiteControllers' => esc_html__( 'White Controls', 'elementor-hero' ),
    					'blackControllers' => esc_html__( 'Black Controls', 'elementor-hero' ),
    				],
    				'default' => esc_html__( 'whiteControllers', 'elementor-hero' ),
    			]
    );

    $this->add_control(
      'playerWidth',
      [
        'label' => esc_html__( 'Player Width', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 50,
        'max' => 10000,
        'step' => 1,
        'default' => 355,
      ]
    );

    $this->add_control(
      'imageHeight',
      [
        'label' => esc_html__( 'Image Height', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 50,
        'max' => 10000,
        'step' => 1,
        'default' => 355,
      ]
    );

    $this->add_control(
			'responsive',
			[
				'label' => esc_html__( 'Responsive', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

    $this->add_control(
			'autoPlay',
			[
				'label' => esc_html__( 'Auto Play', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

    $this->add_control(
			'centerPlayer',
			[
				'label' => esc_html__( 'Center Player', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);

    $this->add_control(
		'noImageAvailable',
		[
			'label' => esc_html__( 'Default "No Image Available"', 'elementor-hero' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );

    $this->add_control(
      'stickyx',
      [
        'label' => esc_html__( 'Sticky', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );

    $this->add_control(
      'startMinified',
      [
        'label' => esc_html__( 'Start Minified', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'false',
        'description' => esc_html__( 'it needs Sticky set to true', 'elementor-hero' ),
      ]
    );

    $this->add_control(
      'showOnlyPlayButton',
      [
        'label' => esc_html__( 'Show Only Play Button', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );

    $this->add_control(
      'grabLastFmPhoto',
      [
        'label' => esc_html__( 'Grab Artist Photo', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );

    $this->add_control(
      'showVolume',
      [
        'label' => esc_html__( 'Show Volume', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );

    $this->add_control(
      'showTitle',
      [
        'label' => esc_html__( 'Show Song Title and Author', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );


    $this->add_control(
      'songTitleColor',
      [
        'label' => esc_html__( 'Song Title - Text Color', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#bfbfbf',
      ]
    );

    $this->add_control(
      'authorTitleColor',
      [
        'label' => esc_html__( 'Author Title - Text Color', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#ffffff',
      ]
    );

    $this->add_control(
      'showRadioStation',
      [
        'label' => esc_html__( 'Show Radio Station', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );

    $this->add_control(
      'radioStationColor',
      [
        'label' => esc_html__( 'Radio Station - Text Color', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#ffffff',
      ]
    );

    $this->add_control(
      'lineSeparatorColor',
      [
        'label' => esc_html__( 'Line Separator Color', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#7d7d7d',
        'description' => esc_html__( 'between Song Title & Song Author', 'elementor-hero' ),
      ]
    );

    $this->add_control(
      'frameBehindTextColor',
      [
        'label' => esc_html__( 'Background Color Beneath Song Title', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#000000',
        'label_block' => true,
      ]
    );

    $this->add_control(
      'frameBehindButtonsColor',
      [
        'label' => esc_html__( 'Background Color Beneath Radio Station Title', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#454545',
        'label_block' => true,
      ]
    );

    $this->add_control(
      'playerBorderSize',
      [
        'label' => esc_html__( 'Player Border Size', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 50,
				'step' => 1,
				'default' => 0,
      ]
    );

    $this->add_control(
      'playerBorderColor',
      [
        'label' => esc_html__( 'Player Border Color', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#000000',
      ]
    );

    $this->add_control(
      'nowPlayingInterval',
      [
        'label' => esc_html__( 'Refresh Interval for Now-Playing Info', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 30,
				'max' => 100000,
				'step' => 5,
				'default' => 35,
      ]
    );

    $this->add_control(
      'delay',
      [
        'label' => esc_html__( 'Player Loading Delay', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 60,
				'step' => 1,
				'default' => 1,
      ]
    );


    $this->add_control(
      'preserveOriginalUpperLowerCase',
      [
        'label' => esc_html__( 'Use The Original Upper&LowerCase', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'false',
        'description' => esc_html__( 'for Song & Author As It Is In the Radio Metadata file', 'elementor-hero' ),
      ]
    );

    $this->add_control(
      'showTwitterBut',
      [
        'label' => esc_html__( 'Show Twitter Button', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );

    $this->add_control(
      'showFacebookBut',
      [
        'label' => esc_html__( 'Show FaceBook Button', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );

    $this->add_control(
      'facebookAppID',
      [
        'label' => esc_html__( 'FaceBook AppID', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );

    $this->add_control(
      'iceCastFirst',
      [
        'label' => esc_html__( 'Check IceCast Metadata File First', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
        'label_off' => esc_html__( 'No', 'elementor-hero' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );

    $this->end_controls_section();

    /*history controls*/
    $this->start_controls_section(
      'history_content',
      [
        'label' => esc_html__( 'History Settings', 'elementor-hero' ),
      ]
    );

    $this->add_control(
			'showHistoryOnInit',
			[
				'label' => esc_html__( 'Show History On Init', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

    $this->add_control(
			'showHistoryBut',
			[
				'label' => esc_html__( 'Show History Button', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

    $this->add_control(
			'showHistory',
			[
				'label' => esc_html__( 'Show History', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-hero' ),
				'label_off' => esc_html__( 'No', 'elementor-hero' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

    $this->add_control(
      'translateReadingData',
      [
        'label' => esc_html__( 'Translate Reading Data', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => esc_html__( 'reading data...', 'elementor-hero' ),
      ]
    );

    $this->add_control(
      'historyTranslate',
      [
        'label' => esc_html__( 'Translate History Title', 'elementor-hero' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => esc_html__( 'HISTORY - latest played songs', 'elementor-hero' ),
      ]
    );

    $this->add_control(
			'historyTitleColor',
			[
				'label' => esc_html__( 'History Title Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => '#858585',
			]
		);

    $this->add_control(
			'historyBgColor',
			[
				'label' => esc_html__( 'History Background Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => '#ebebeb',
			]
		);

    $this->add_control(
			'historyRecordBgColor',
			[
				'label' => esc_html__( 'History Record Background Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => 'transparent',
			]
		);

    $this->add_control(
			'historyRecordBottomBorderColor',
			[
				'label' => esc_html__( 'History Record Bottom Border Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => 'transparent',
			]
		);

    $this->add_control(
			'historyRecordSongColor',
			[
				'label' => esc_html__( 'History Record Song Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => '#000000',
			]
		);

    $this->add_control(
      'historyRecordTitleLimit',
      [
        'label' => esc_html__( 'History Record Title Limit', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 1,
				'default' => 25,
      ]
    );

    $this->add_control(
			'historyRecordSongBottomBorderColor',
			[
				'label' => esc_html__( 'History Record Song Bottom Border Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => '#d0d0d0',
        'label_block' => true,
			]
		);

    $this->add_control(
			'historyRecordAuthorColor',
			[
				'label' => esc_html__( 'History Record Author Color', 'elementor-hero' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
        'alpha' => false,
        'default' => '#6d6d6d',
			]
		);

    $this->add_control(
      'historyRecordAuthorLimit',
      [
        'label' => esc_html__( 'History Record Author Limit', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 1,
				'default' => 36,
      ]
    );

    $this->add_control(
      'numberOfThumbsPerScreen',
      [
        'label' => esc_html__( 'Number Of Items Per Screen', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 1,
				'default' => 3,
      ]
    );

    $this->add_control(
      'historyPadding',
      [
        'label' => esc_html__( 'History Padding', 'elementor-hero' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 1,
				'default' => 16,
      ]
    );

    $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function render() {
    $pathToAjaxFiles_aux=plugin_dir_url(__FILE__).'audio6_html5_radio_history/';
    $rand_id=rand(10,999999);
    $settings = $this->get_settings_for_display();
    ?>
    <script>
  		jQuery(function() {
          setTimeout(function(){
          			jQuery("#lbg_audio6_html5_shoutcast_<?php echo $rand_id; ?>").audio6_html5({
                  radio_stream:"<?php echo $settings['radio_stream']; ?>",
                  radio_name:"<?php echo $settings['radio_name']; ?>",
                  azuracast_api_nowplaying_url:"<?php echo $settings['azuracast_api_nowplaying_url']; ?>",
                  url_custom_metdata_file:"<?php echo $settings['url_custom_metdata_file']; ?>",
                  metadata_file_type:"<?php echo $settings['metadata_file_type']; ?>",
                  optional_images_path:"<?php echo $settings['optional_images_path']; ?>",
                  mscp_pro_api_url:"<?php echo $settings['mscp_pro_api_url']; ?>",
                  playerWidth:<?php echo $settings['playerWidth']; ?>,
                  imageHeight:<?php echo $settings['imageHeight']; ?>,
                  skin:"<?php echo $settings['skin']; ?>",
                  responsive:<?php echo (($settings['responsive']==='true')?'true':'false'); ?>,
                  grabLastFmPhoto:<?php echo (($settings['grabLastFmPhoto']==='true')?'true':'false'); ?>,
                  azuracast_get_image:<?php echo (($settings['azuracast_get_image']==='true')?'true':'false'); ?>,
                  autoPlay:<?php echo (($settings['autoPlay']==='true')?'true':'false'); ?>,
                  songTitleColor:"<?php echo $settings['songTitleColor']; ?>",
                  authorTitleColor:"<?php echo $settings['authorTitleColor']; ?>",
                  lineSeparatorColor:"<?php echo $settings['lineSeparatorColor']; ?>",
                  radioStationColor:"<?php echo $settings['radioStationColor']; ?>",
                  frameBehindTextColor:"<?php echo $settings['frameBehindTextColor']; ?>",
                  frameBehindButtonsColor:"<?php echo $settings['frameBehindButtonsColor']; ?>",
                  sticky:<?php echo (($settings['stickyx']==='true')?'true':'false'); ?>,
                  startMinified:<?php echo (($settings['startMinified']==='true')?'true':'false'); ?>,
                  showOnlyPlayButton:<?php echo (($settings['showOnlyPlayButton']==='true')?'true':'false'); ?>,
                  centerPlayer:<?php echo (($settings['centerPlayer']==='true')?'true':'false'); ?>,
                  playerBorderSize:<?php echo $settings['playerBorderSize']; ?>,
                  playerBorderColor:"<?php echo $settings['playerBorderColor']; ?>",
                  showFacebookBut:<?php echo (($settings['showFacebookBut']==='true')?'true':'false'); ?>,
                  facebookAppID:"<?php echo $settings['facebookAppID']; ?>",
                  showTwitterBut:<?php echo (($settings['showTwitterBut']==='true')?'true':'false'); ?>,
                  showVolume:<?php echo (($settings['showVolume']==='true')?'true':'false'); ?>,
                  showRadioStation:<?php echo (($settings['showRadioStation']==='true')?'true':'false'); ?>,
                  showTitle:<?php echo (($settings['showTitle']==='true')?'true':'false'); ?>,
                  showHistoryBut:<?php echo (($settings['showHistoryBut']==='true')?'true':'false'); ?>,
                  showHistory:<?php echo (($settings['showHistory']==='true')?'true':'false'); ?>,
                  showHistoryOnInit:<?php echo (($settings['showHistoryOnInit']==='true')?'true':'false'); ?>,
                  translateReadingData:"<?php echo $settings['translateReadingData']; ?>",
                  historyTranslate:"<?php echo $settings['historyTranslate']; ?>",
                  historyTitleColor:"<?php echo $settings['historyTitleColor']; ?>",
                  historyBgColor:"<?php echo $settings['historyBgColor']; ?>",
                  historyRecordBgColor:"<?php echo $settings['historyRecordBgColor']; ?>",
                  historyRecordBottomBorderColor:"<?php echo $settings['historyRecordBottomBorderColor']; ?>",
                  historyRecordSongColor:"<?php echo $settings['historyRecordSongColor']; ?>",
                  historyRecordSongBottomBorderColor:"<?php echo $settings['historyRecordSongBottomBorderColor']; ?>",
                  historyRecordAuthorColor:"<?php echo $settings['historyRecordAuthorColor']; ?>",
                  numberOfThumbsPerScreen:<?php echo $settings['numberOfThumbsPerScreen']; ?>,
                  historyPadding:<?php echo $settings['historyPadding']; ?>,
                  historyRecordTitleLimit:<?php echo $settings['historyRecordTitleLimit']; ?>,
                  historyRecordAuthorLimit:<?php echo $settings['historyRecordAuthorLimit']; ?>,
                  pathToAjaxFiles:"<?php echo $pathToAjaxFiles_aux; ?>",
                  nowPlayingInterval:<?php echo $settings['nowPlayingInterval']; ?>,
                  preserveOriginalUpperLowerCase:<?php echo (($settings['preserveOriginalUpperLowerCase']==='true')?'true':'false'); ?>,
                  noImageAvailable:"<?php echo $settings['noImageAvailable']['url']; ?>",
                  iceCastFirst:<?php echo (($settings['iceCastFirst']==='true')?'true':'false'); ?>
                });
          },<?php echo $settings['delay']*1000; ?>);
  		});
  	</script>
    <div class="audio6_html5">
            <div id="lbg_audio6_html5_shoutcast_<?php echo $rand_id; ?>"></div>
     </div>
    <?php
  }

  /**
   * Render the widget output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function content_template() {

  }
}
